OC.L10N.register(
    "sharebymail",
    {
    "Shared with {email}" : "Delt med {email}",
    "Shared with {email} by {actor}" : "Delt med {email} af {actor}",
    "Password for mail share sent to {email}" : "Password for mail deling er sendt til {email}",
    "Password for mail share sent to you" : "Password for mail deling er sendt til dig",
    "You shared {file} with {email} by mail" : "Du delte {file} med {email} via e-mail",
    "{actor} shared {file} with {email} by mail" : "{actor} delte {file} med {email} via e-mail",
    "Password to access {file} was sent to {email}" : "Password for adgang {file} blev sendt til {email}",
    "Password to access {file} was sent to you" : "Password for adgang {file} blev sendt til dig.",
    "Share by mail" : "Delt med mail",
    "Failed to send share by email" : "Kunne ikke sende deling via e-mail",
    "%1$s shared »%2$s« with you" : "%1$s delte \"%2$s\" med dig",
    "%1$s shared »%2$s« with you." : "%1$s delte »%2$s« med dig",
    "Click the button below to open it." : "Klik på knappen nedenunder for at åbne.",
    "Open »%s«" : "Åbn »%s«",
    "%1$s via %2$s" : "%1$s via %2$s",
    "Password to access »%1$s« shared to you by %2$s" : "Adgangskode for at få adgang »%1$s« delt til dig af %2$s",
    "Password to access »%s«" : "Kodeord for adgang til »%s«",
    "It is protected with the following password:" : "Beskyttet med følgende adgangskode:",
    "%1$s shared »%2$s« with you and wants to add:" : "%1$s delte »%2$s« med dig og vil gerne tilføje:",
    "%1$s shared »%2$s« with you and wants to add" : "%1$s delte »%2$s« med dig og vil gerne tilføje",
    "»%s« added a note to a file shared with you" : "»%s« har tilføjet en note til en fil delt med dig",
    "You can choose a different password at any time in the share dialog." : "Du kan til enhver tid vælge et andet password i delings dialogen.",
    "Could not find share" : "Kan ikke finde deling",
    "Send password by mail" : "Send kodeord på mail",
    "Sharing %1$s failed, because this item is already shared with user %2$s" : "Deling af %1$s mislykkedes, fordi dette element allerede er delt med bruger%2$s",
    "Allows users to share a personalized link to a file or folder by putting in an email address." : "Tillad brugere at dele et personligt link til en fil eller folder ved at skrive en email ind."
},
"nplurals=2; plural=(n != 1);");
